\name{searchStandardPeaks}
\alias{searchStandardPeaks}
\title{
searchStandardPeaks
}
\description{
The function looks for the standard size ladder in an electropherogram (ABIF) file. 
ABIF files have to be imported using \code{seqinr::read.abif()}. 
If successful, the function returns the peak positions the size standard.
}
\usage{
searchStandardPeaks(x_abifile, 
                    refchannel = 5, 
                    reference = r_npk, 
                    npks = 15, 
                    rsizes = r_sizes, 
                    x_tmin = 2, 
                    x_tmax = 3, 
                    x_thres = 0.5, 
                    x_step = 0.1, 
                    dist_thres = 0.01, 
                    plotit = FALSE, 
                    ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x_abifile}{
list generated by \code{seqinr::read.abif} representing the ABIF file
}
  \item{refchannel}{
channel number of the size ladder. See \code{seqinr::peakabif}.
}
  \item{reference}{
contains normalized peak positions. Peak positions can be extracted from an ABIF
file with \code{seqinr::peakabif}. Normalization is achieved with \code{normPeaks}.  
}
  \item{npks}{
number of expected peaks
}
  \item{rsizes}{
sizes of reference peaks in basepairs; peaks not to be counted are given as NA.
}
  \item{x_tmin}{
scaled (1:1000) starting time for the time axis for x_abifile (see function 
\code{seqinr::peakabif})
}
  \item{x_tmax}{
scaled (1:1000) ending time for the time axis for x_abifile (see function 
\code{seqinr::peakabif})
}
  \item{x_thres}{
threshold, above which peaks are looked for in x_abifile (see function 
\code{seqinr::peakabif})
}
  \item{x_step}{
step, by which x_thres is decreased and x_tmin increased until standard peaks 
are retrieved
}
  \item{dist_thres}{
euclidian distance of peak vectors, below which identity of references in 
x_abifile and reference is assumed
}
  \item{plotit}{
logical value stating whether a time->bp plot should be shown
}
  \item{\dots}{
arguments passed to \code{plot}
}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
}
\value{
numeric vector containing the positions of the standard peaks
}
\references{
package \code{seqinr} by Charif, D. and Lobry, J.R. (2007)
}
\author{
Johannes Elias
}
\note{
%%  ~~further notes~~
}
\section{Warning }{
A warning is issued if standard peaks cannot be retrieved.
}
\seealso{
sizeCaller
}
\examples{
# returns positions of reference peaks in reference file
searchStandardPeaks(r_abif)

# show a nice plot of the time->bp conversion function
searchStandardPeaks(r_abif,plotit=TRUE)
}
